@@ -1,8 +1,9 @@
 /* FSNIconsView.h
  *  
- * Copyright (C) 2004-2013 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2024 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
+ * Authors: Enrico Sersale
+ *          Riccardo Mottola
  * Date: March 2004
  *
  * This file is part of the GNUstep FSNode framework
@@ -19,7 +20,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 
@@ -53,16 +54,16 @@
   int iconSize;
   int labelTextSize;
   NSFont *labelFont;
-  int iconPosition;
+  NSCellImagePosition iconPosition;
 
   NSSize gridSize;
-  int colcount;
+  NSInteger colItemsCount;
 
   BOOL isDragTarget;
   BOOL forceCopy;
   
   NSString *charBuffer;	
-  NSTimeInterval lastKeyPressed;
+  NSTimeInterval lastKeyPressedTime;
   
   NSColor *backColor;
   NSColor *textColor;
@@ -118,8 +119,8 @@
 - (int)iconSize;
 - (void)setLabelTextSize:(int)size;
 - (int)labelTextSize;
-- (void)setIconPosition:(int)pos;
-- (int)iconPosition;
+- (void)setIconPosition:(NSCellImagePosition)pos;
+- (NSCellImagePosition)iconPosition;
 - (void)updateIcons;
 - (id)repOfSubnode:(FSNode *)anode;
 - (id)repOfSubnodePath:(NSString *)apath;
