@@ -1,6 +1,6 @@
 /* FSNTextCell.h
  *  
- * Copyright (C) 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2013 Free Software Foundation, Inc.
  *
  * Author: Enrico Sersale <enrico@imago.ro>
  * Date: March 2004
@@ -19,17 +19,15 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #ifndef FSN_TEXT_CELL_H
 #define FSN_TEXT_CELL_H
 
-#include <Foundation/Foundation.h>
-#include <AppKit/NSTextFieldCell.h>
-#include "FSNodeRep.h"
-
-typedef NSString *(*cutIMP)(id, SEL, id, float);
+#import <Foundation/Foundation.h>
+#import <AppKit/NSTextFieldCell.h>
+#import "FSNodeRep.h"
 
 @class NSImage;
 
@@ -38,11 +36,8 @@ typedef NSString *(*cutIMP)(id, SEL, id, float);
   NSDictionary *fontAttr;
   NSString *dots;
   NSSize titlesize;
-  float dtslenght;
   BOOL dateCell;
-  NSString *uncuttedTitle; 
-	SEL cutTitleSel;
-	cutIMP cutTitle;
+  NSString *uncutTitle; 
   NSImage *icon;
 }
 
@@ -50,7 +45,7 @@ typedef NSString *(*cutIMP)(id, SEL, id, float);
 
 - (NSImage *)icon;
 
-- (float)uncuttedTitleLenght;
+- (float)uncutTitleLenght;
 
 - (void)setDateCell:(BOOL)value;
 
