@@ -1,8 +1,9 @@
 /* FSNodeRep.h
  *  
- * Copyright (C) 2004-2016 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2024 Free Software Foundation, Inc.
  *
- * Author: Enrico Sersale <enrico@imago.ro>
+ * Authors: Enrico Sersale
+ *          Riccardo Mottola
  * Date: March 2004
  *
  * This file is part of the GNUstep FSNode framework
@@ -19,7 +20,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+ * Foundation, Inc., 31 Milk Street #960789 Boston, MA 02196 USA.
  */
 
 #ifndef FSNODE_REP_H
@@ -79,9 +80,9 @@ typedef enum FSNSelectionMask {
 
 - (int)iconSize;
 
-- (void)setIconPosition:(unsigned int)ipos;
+- (void)setIconPosition:(NSCellImagePosition)ipos;
 
-- (int)iconPosition;
+- (NSCellImagePosition)iconPosition;
 
 - (NSRect)labelRect;
 
@@ -356,15 +357,11 @@ typedef enum FSNSelectionMask {
   NSMutableSet *reservedNames;
   NSMutableSet *volumes;
   NSString *rootPath;
-
-  unsigned systype;
     
   NSMutableDictionary *iconsCache;
   NSMutableDictionary *tumbsCache;
   NSString *thumbnailDir;
   BOOL usesThumbnails;  
-  
-  BOOL oldresize;  
 
   NSImage *multipleSelIcon;
   NSImage *openFolderIcon;
@@ -376,7 +373,6 @@ typedef enum FSNSelectionMask {
   float labelWFactor;
     
   NSFileManager *fm;
-  id ws;    
 }
 
 + (FSNodeRep *)sharedInstance;
@@ -445,8 +441,6 @@ typedef enum FSNSelectionMask {
 
 - (BOOL)isReservedName:(NSString *)name;
 
-- (unsigned)systemType;
-
 - (void)setUseThumbnails:(BOOL)value;
 
 - (BOOL)usesThumbnails;
